@@ -1,10 +1,12 @@
 """
 ElasticTabstops package
 Converts text indented/aligned with elastic tabstops
-see: http://nickgravgaard.com/elastictabstops/
+see: https://nickgravgaard.com/elastictabstops/
+
+Repo at: https://github.com/nickgravgaard/elastic-tabstops-py
 """
 
-# Copyright (c) 2007-2013 Nick Gravgaard <me@nickgravgaard.com>
+# Copyright (c) 2007-2022 Nick Gravgaard <nick@nickgravgaard.com>
 # This code is licensed under the MIT Licence - see LICENCE.txt
 
 from elastictabstops.classes import Text, Table
